Re-exports
pub use crate::protocol::codec::QueueSendResult;pub use crate::protocol::codec::QueueSendStatus;
Structs
- Actor
Handle - Actor
Handle Stateless - Resolved
Actor Handle - An actor handle whose query has already resolved to a concrete actor ID. Raw requests through this handle never repeat Engine actor lookup.
- Send
AndWait Opts - Send
Opts