pub struct ActorHandle { /* private fields */ }Implementations
Sourceimpl ActorHandle
impl ActorHandle
pub fn new( remote_manager: RemoteManager, params: Option<JsonValue>, query: ActorQuery, client_shutdown_tx: Arc<Sender<()>>, transport_kind: TransportKind, encoding_kind: EncodingKind, ) -> Self
pub fn connect(&self) -> ActorConnection
Methods from Deref<Target = ActorHandleStateless>
pub async fn action( &self, name: &str, args: Vec<JsonValue>, ) -> Result<JsonValue>
pub async fn send( &self, name: &str, body: impl Serialize, _opts: SendOpts, ) -> Result<()>
pub async fn send_and_wait( &self, name: &str, body: impl Serialize, opts: SendAndWaitOpts, ) -> Result<QueueSendResult>
pub async fn fetch( &self, path: &str, method: Method, headers: HeaderMap, body: Option<Bytes>, ) -> Result<Response>
Sourcepub async fn resolve_handle(&self) -> Result<ResolvedActorHandle>
pub async fn resolve_handle(&self) -> Result<ResolvedActorHandle>
Resolves this query to a concrete actor, preserving get-or-create behavior for creating handles.
Sourcepub async fn resolve_optional(&self) -> Result<Option<ResolvedActorHandle>>
pub async fn resolve_optional(&self) -> Result<Option<ResolvedActorHandle>>
Resolves a non-creating actor query without collapsing absence into a stringly error. Get-or-create and create queries are rejected because their absence has different semantics.
pub async fn web_socket( &self, path: &str, protocols: Option<Vec<String>>, ) -> Result<RawWebSocket>
pub fn gateway_url(&self) -> Result<String>
pub fn get_gateway_url(&self) -> Result<String>
pub async fn reload(&self) -> Result<()>
pub async fn resolve(&self) -> Result<String>